# Welcome to salmongis


[![image](https://img.shields.io/pypi/v/salmongis.svg)](https://pypi.python.org/pypi/salmongis)


**A geospatial package**


-   Free software: MIT License
-   Documentation: <https://GISCreations.github.io/salmongis>
    

## Features

-   TODO
